# START_VERSION_BLOCK
VERSION_MAJOR = 0
VERSION_MINOR = 13
VERSION_BUILD = 0
VERSION_ALPHA = 1
# END_VERSION_BLOCK

__version__ = f"{VERSION_MAJOR}.{VERSION_MINOR}.{VERSION_BUILD}" + (
    f"a{VERSION_ALPHA}" if VERSION_ALPHA else ""
)
